@@ -9,17 +9,22 @@ from .update import UpdateHandler
 class QueryHandler(UpdateHandler):
     def __init__(
         self,
+        callback: QueryCallback,
         button: CallbackButton | None = None,
-        reply_text: str | None = None,
-        reply_keyboard: InlineKeyboard | None = None,
     ) -> None:
-        super().__init__()
         self._button = button
-        self._reply_text = reply_text
-        self._reply_keyboard = reply_keyboard
+        super().__init__(callback)
 
     def get_trigger(self) -> QueryTrigger:
         return QueryTrigger(self._button)
 
-    def get_callback(self) -> QueryCallback:
-        return QueryCallback(self._reply_text, self._reply_keyboard)
+
+class QueryReplyHandler(QueryHandler):
+    def __init__(
+        self,
+        button: CallbackButton | None = None,
+        text: str | None = None,
+        keyboard: InlineKeyboard | None = None,
+    ) -> None:
+        callback = QueryCallback(text, keyboard)
+        super().__init__(callback, button)
