@@ -1,30 +1,25 @@
-from abc import ABC, abstractmethod
 from copy import deepcopy
 
 import telegram
 from botty_core import Callback, Handler
-from botty_core.types import Context, PTBHandler, Update
+from botty_core.types import Context, PTBHandler
 
 from botty.triggers import UpdateTrigger
 
 
-class UpdateHandler(Handler, ABC):
-    def __init__(self) -> None:
-        self._update: Update | None = None
-        self._context: Context | None = None
-
-    def build(self) -> PTBHandler:
-        return self.get_trigger().make_handler(self.handle)
+class UpdateHandler(Handler):
+    def __init__(self, callback: Callback) -> None:
+        self._callback = callback
+        self._trigger = self.get_trigger()
 
     def get_trigger(self) -> UpdateTrigger:
         return UpdateTrigger()
 
+    def build(self) -> PTBHandler:
+        return self._trigger.make_handler(self.handle)
+
     async def handle(self, update: telegram.Update, context: Context) -> None:
-        callback = deepcopy(self.get_callback())
+        callback = deepcopy(self._callback)
         callback.set_update(update, context)
         await callback.prepare()
         await callback.run()
-
-    @abstractmethod
-    def get_callback(self) -> Callback:
-        pass
